package ru.ulstu.news;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Service;
import ru.ulstu.files.FileSystemStorageService;
import ru.ulstu.files.FileUtil;

import javax.validation.constraints.NotNull;
import java.io.IOException;
import java.util.Date;
import java.util.List;

@Service
public class NewsService {
    private final NewsRepository newsRepository;

    public NewsService(NewsRepository newsRepository) {
        this.newsRepository = newsRepository;
    }

    public void create(String title, String text) {
        newsRepository.save(new News(title, new Date(), text));
    }

    public void create(News news) {
        news.setDate(new Date());
        newsRepository.save(news);
    }

    public void save(News news) throws IOException {
        String fileName = System.currentTimeMillis() + "";
        news.setImageFileName(fileName);

        if (news.getId() != null && (news.getId() != 0)) {
            newsRepository.save(news);
        } else {
            create(news);
        }

        FileUtil.saveFile(FileSystemStorageService.UPLOAD_DIR, fileName, news.getImageFile());
    }

    public News getById(@NotNull Integer id) {
        return newsRepository
                .findById(id)
                .orElseThrow(() -> new RuntimeException("Новость не найдена"));
    }

    public List<News> getAll() {
        return newsRepository.findAll();
    }

    public void delete(Integer id) {
        newsRepository.deleteById(id);
    }

    public List<News> getLast() {
        return newsRepository.findFirst3ByOrderByDateDesc();
    }

    public Page<News> getNews(Pageable pageable) {
        return newsRepository.findByOrderByDateDesc(pageable);
    }
}
